==> stj-1.3.0-1.tgz: package/Dictionary.js <==
/*jslint indent:4 */
/*global define, module_, class_, include_, use_, extend_, static_, properties_, property_, globals_ */
/**
 * @projectDescription Dictionary module
 *
 * @author Julien Polo<julien.polo@gmail.com>
 * @version 1.0.1
 */
define("stj/Dictionary", [ "stj" ], function (stj) {
    "use strict";


    /**
     * @class Dictionary
     */
    class_('Dictionary', null, function () {
        var
            isUndefined = Object.isUndefined,
            objectHas = Object.has,
            objectGet = Object.get,
            objectSet = Object.set,
            objectUnset = Object.unset,
            objectUpdate = Object.update;

        include_('stj.Enumerable');
        properties_({
            /**
             * Dictionary constructor
             *
             * @constructor
             * @param {Object=} data
             */
            initialize: function initialize(data) {
                this.update(data);
            },

            /**
             * Destroy the dictionary
             */
            finalize: function finalize() {
                this.clear();
            },

            /**
             * Merge all the objectExtension into hash data
             *
             * @param {Dictionary|Object} objectExtension
             * @return this
             */
            update: function update(objectExtension) {
                return objectUpdate(this, objectExtension, true);
            },

            /**
             * Return true if data[key] is set
             *
             * @param {string} key
             * @return {boolean}
             */
            isset: function isset(key) {
                return objectHas(this, key);
            },

            __get__: function __get__(key, defaultValue) {
                return objectHas(this, key) ? this[key] : defaultValue;
            },

            __set__: function __set__(key, value) {
                if (!isUndefined(value)) {
                    if (!isUndefined(this[key]) && !objectHas(this, key)) {
                        throw new Error('Property "' + key + '" is internal could not be set');
                    }
                    this[key] = value;
                } else {
                    objectUnset(this, key);
                }

                return this;
            },

            __unset__: function __unset__(key) {
                delete this[key];
            },

            /**
             * Set key to `defaultValue` if not already set and return the value.
             *
             * @param {string|number} key
             * @param {*} defaultValue
             * @return {*}
             */
            setDefault: function setDefault(key, defaultValue) {
                var value = objectGet(this, key);
                if (isUndefined(value)) {
                    value = isUndefined(defaultValue) ? null : defaultValue;
                    this[key] = value;
                }
                return value;
            }
        });
    });
    
    return use_('Dictionary');
});

==> stj-1.3.0-2.tgz: package/Dictionary.js <==
/*jslint indent:4 */
/*global define, module_, class_, include_, use_, extend_, static_, properties_, property_, globals_ */
/**
 * @projectDescription Dictionary module
 *
 * @author Julien Polo<julien.polo@gmail.com>
 * @version 1.0.1
 */
define("stj/Dictionary", [ "stj" ], function (stj) {
    "use strict";


    /**
     * @class Dictionary
     */
    class_('Dictionary', Object, function () {
        var
            isUndefined = Object.isUndefined,
            objectHas = Object.has,
            objectGet = Object.get,
            objectUnset = Object.unset,
            objectUpdate = Object.update;

        include_('stj.Enumerable');
        properties_({
            /**
             * Dictionary constructor
             *
             * @constructor
             * @param {Object=} data
             */
            initialize: function initialize(data) {
                this.update(data);
            },

            /**
             * Destroy the dictionary
             */
            finalize: function finalize() {
                this.clear();
            },

            /**
             * Merge all the objectExtension into hash data
             *
             * @param {Dictionary|Object} objectExtension
             * @return this
             */
            update: function update(objectExtension) {
                return objectUpdate(this, objectExtension, true);
            },

            /**
             * Return true if data[key] is set
             *
             * @param {string} key
             * @return {boolean}
             */
            isset: function isset(key) {
                return objectHas(this, key);
            },

            __get__: function __get__(key, defaultValue) {
                return objectHas(this, key) ? this[key] : defaultValue;
            },

            __set__: function __set__(key, value) {
                if (!isUndefined(value)) {
                    if (!isUndefined(this[key]) && !objectHas(this, key)) {
                        throw new Error('Property "' + key + '" is internal could not be set');
                    }
                    this[key] = value;
                } else {
                    objectUnset(this, key);
                }

                return this;
            },

            __unset__: function __unset__(key) {
                delete this[key];
            },

            /**
             * Set key to `defaultValue` if not already set and return the value.
             *
             * @param {string|number} key
             * @param {*} defaultValue
             * @return {*}
             */
            setDefault: function setDefault(key, defaultValue) {
                var value = objectGet(this, key);
                if (isUndefined(value)) {
                    value = isUndefined(defaultValue) ? null : defaultValue;
                    this[key] = value;
                }
                return value;
            }
        });
    });

    return use_('Dictionary');
});
